@@ -12,7 +12,7 @@
 #' This function computes and plots the cumulative average strike rate  of a batsman
 #'
 #' @usage
-#' batsmanCumulativeStrikeRate(df,name= "A Leg Glance",staticIntv=1)
+#' batsmanCumulativeStrikeRate(df,name= "A Leg Glance",dateRange, staticIntv=1)
 #'
 #' @param df
 #' Data frame
@@ -20,6 +20,9 @@
 #' @param name
 #' Name of batsman
 #'
+#' @param dateRange
+#' Date interval to consider
+#'
 #' @param staticIntv
 #' Static or interactive -staticIntv =1 (static plot) &  staticIntv =2 (interactive  plot)
 #'
@@ -38,7 +41,7 @@
 #' \dontrun{
 #' #Get the data frame for Kohli
 #' kohli <- getBatsmanDetails(team="India",name="Kohli",dir=pathToFile)
-#' batsmanCumulativeStrikeRate(kohli,"Kohli")
+#' batsmanCumulativeStrikeRate(kohli,"Kohli",dateRange)
 #' }
 #' @seealso
 #' \code{\link{batsmanCumulativeAverageRuns}}
@@ -50,9 +53,10 @@
 #' @export
 #'
 #'
-batsmanCumulativeStrikeRate <- function(df,name= "A Leg Glance",staticIntv=1){
+batsmanCumulativeStrikeRate <- function(df,name= "A Leg Glance",dateRange,staticIntv=1){
     strikeRate=cs=no=NULL
     ggplotly=NULL
+    df=df %>% filter(date >= dateRange[1] & date <= dateRange[2])
     b <- select(df,strikeRate)
     b$no<-seq.int(nrow(b))
     c <- select(b,no,strikeRate)
