@@ -15,7 +15,7 @@
 #' opposition in all matches against the opposition
 #'
 #' @usage
-#' teamBowlersWicketRunsOppnAllMatches(matches,main,opposition,plot=TRUE)
+#' teamBowlersWicketRunsOppnAllMatches(matches,main,opposition,plot=1)
 #'
 #' @param matches
 #' The data frame of all matches between a team the opposition. This dataframe can be obtained with
@@ -28,7 +28,7 @@
 #' The opposing team
 #'
 #' @param plot
-#' If plot=TRUE then a plot is displayed else a dataframe is returned
+#' plot=1 (static),plot=2(interactive),plot=3(table)
 #'
 #' @return None or dataframe
 #' The return depends on the value of the plot
@@ -61,8 +61,9 @@
 #'
 #' @export
 #'
-teamBowlersWicketRunsOppnAllMatches <- function(matches,main,opposition,plot=TRUE){
+teamBowlersWicketRunsOppnAllMatches <- function(matches,main,opposition,plot=1){
     team=bowler=ball=NULL
+    ggplotly=NULL
     runs=over=wickets=NULL
     byes=legbyes=noballs=wides=runsConceded=NULL
     extras=wicketFielder=wicketKind=wicketPlayerOut=NULL
@@ -108,7 +109,7 @@ teamBowlersWicketRunsOppnAllMatches <- function(matches,main,opposition,plot=TRU
         l[is.na(l$wickets),]$wickets=0
     }
 
-    if(plot==TRUE){
+    if(plot == 1){ #ggplot2
         plot.title = paste("Wicket taken cs Runs conceded -",main," Vs ",opposition,"(all matches)",sep="")
         ggplot(data=l,aes(x=factor(wickets),y=runs,fill=factor(wickets))) +
             facet_wrap( ~ bowler,scales = "fixed", ncol=8) +
@@ -117,6 +118,16 @@ teamBowlersWicketRunsOppnAllMatches <- function(matches,main,opposition,plot=TRU
             ggtitle(bquote(atop(.(plot.title),
                                     atop(italic("Data source:http://cricsheet.org/"),"")))) +
             theme(axis.text.x = element_text(angle = 90, hjust = 1))
+    } else if(plot == 2){ #ggplotly
+        plot.title = paste("Wicket taken cs Runs conceded -",main," Vs ",opposition,"(all matches)",sep="")
+        g <- ggplot(data=l,aes(x=factor(wickets),y=runs,fill=factor(wickets))) +
+            facet_wrap( ~ bowler,scales = "fixed", ncol=8) +
+            geom_bar(stat="identity") +
+            xlab("Number of wickets") + ylab('Runs conceded') +
+            ggtitle(plot.title) +
+            theme(axis.text.x = element_text(angle = 90, hjust = 1))
+        ggplotly(g,height=500)
+
     } else {
         l
     }
